@@ -25,7 +25,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: syscallent.h,v 1.16 2004/10/06 22:23:33 roland Exp $
+ *	$Id: syscallent.h,v 1.22 2006/01/12 22:34:50 roland Exp $
  */
 
 /*
@@ -929,10 +929,10 @@
 	{ 8,	0,	printargs,		"SYS_1023"	}, /* 1023 */
 	{ 0,	0,	printargs,		"ni_syscall"	}, /* 1024 */
 	{ 1,	TP,	sys_exit,		"exit"		}, /* 1025 */
-	{ 3,	TF,	sys_read,		"read"		}, /* 1026 */
-	{ 3,	TF,	sys_write,		"write"		}, /* 1027 */
-	{ 3,	TF,	sys_open,		"open"		}, /* 1028 */
-	{ 1,	0,	sys_close,		"close"		}, /* 1029 */
+	{ 3,	TD,	sys_read,		"read"		}, /* 1026 */
+	{ 3,	TD,	sys_write,		"write"		}, /* 1027 */
+	{ 3,	TD|TF,	sys_open,		"open"		}, /* 1028 */
+	{ 1,	TD,	sys_close,		"close"		}, /* 1029 */
 	{ 2,	0,	sys_creat,		"creat"		}, /* 1030 */
 	{ 2,	TF,	sys_link,		"link"		}, /* 1031 */
 	{ 1,	TF,	sys_unlink,		"unlink"	}, /* 1032 */
@@ -954,26 +954,26 @@
 	{ 4,	0,	sys_ptrace,		"ptrace"	}, /* 1048 */
 	{ 2,	TF,	sys_access,		"access"	}, /* 1049 */
 	{ 0,	0,	sys_sync,		"sync"		}, /* 1050 */
-	{ 1,	0,	sys_fsync,		"fsync"		}, /* 1051 */
-	{ 1,	0,	sys_fdatasync,		"fdatasync"	}, /* 1052 */
+	{ 1,	TD,	sys_fsync,		"fsync"		}, /* 1051 */
+	{ 1,	TD,	sys_fdatasync,		"fdatasync"	}, /* 1052 */
 	{ 2,	TS,	sys_kill,		"kill"		}, /* 1053 */
 	{ 2,	TF,	sys_rename,		"rename"	}, /* 1054 */
 	{ 2,	TF,	sys_mkdir,		"mkdir"		}, /* 1055 */
 	{ 1,	TF,	sys_rmdir,		"rmdir"		}, /* 1056 */
-	{ 1,	0,	sys_dup,		"dup"		}, /* 1057 */
-	{ 1,	0,	sys_pipe,		"pipe"		}, /* 1058 */
+	{ 1,	TD,	sys_dup,		"dup"		}, /* 1057 */
+	{ 1,	TD,	sys_pipe,		"pipe"		}, /* 1058 */
 	{ 1,	0,	sys_times,		"times"		}, /* 1059 */
 	{ 1,	0,	sys_brk,		"brk"		}, /* 1060 */
 	{ 1,	0,	sys_setgid,		"setgid"	}, /* 1061 */
 	{ 0,	0,	sys_getgid,		"getgid"	}, /* 1062 */
 	{ 0,	0,	sys_getegid,		"getegid"	}, /* 1063 */
 	{ 1,	TF,	sys_acct,		"acct"		}, /* 1064 */
-	{ 3,	0,	sys_ioctl,		"ioctl"		}, /* 1065 */
-	{ 3,	0,	sys_fcntl,		"fcntl"		}, /* 1066 */
+	{ 3,	TD,	sys_ioctl,		"ioctl"		}, /* 1065 */
+	{ 3,	TD,	sys_fcntl,		"fcntl"		}, /* 1066 */
 	{ 1,	0,	sys_umask,		"umask"		}, /* 1067 */
 	{ 1,	TF,	sys_chroot,		"chroot"	}, /* 1068 */
 	{ 2,	0,	sys_ustat,		"ustat"		}, /* 1069 */
-	{ 2,	0,	sys_dup2,		"dup2"		}, /* 1070 */
+	{ 2,	TD,	sys_dup2,		"dup2"		}, /* 1070 */
 	{ 2,	0,	sys_setreuid,		"setreuid"	}, /* 1071 */
 	{ 2,	0,	sys_setregid,		"setregid"	}, /* 1072 */
 	{ 3,	0,	printargs,		"getresuid"	}, /* 1073 */
@@ -992,8 +992,8 @@
 	{ 2,	0,	sys_getrusage,		"getrusage"	}, /* 1086 */
 	{ 2,	0,	sys_gettimeofday,	"gettimeofday"	}, /* 1087 */
 	{ 2,	0,	sys_settimeofday,	"settimeofday"	}, /* 1088 */
-	{ 5,	0,	sys_select,		"select"	}, /* 1089 */
-	{ 3,	0,	sys_poll,		"poll"		}, /* 1090 */
+	{ 5,	TD,	sys_select,		"select"	}, /* 1089 */
+	{ 3,	TD,	sys_poll,		"poll"		}, /* 1090 */
 	{ 2,	TF,	sys_symlink,		"symlink"	}, /* 1091 */
 	{ 3,	TF,	sys_readlink,		"readlink"	}, /* 1092 */
 	{ 1,	0,	sys_uselib,		"uselib"	}, /* 1093 */
@@ -1001,14 +1001,14 @@
 	{ 1,	0,	sys_swapoff,		"swapoff"	}, /* 1095 */
 	{ 3,	0,	sys_reboot,		"reboot"	}, /* 1096 */
 	{ 2,	TF,	sys_truncate,		"truncate"	}, /* 1097 */
-	{ 2,	0,	sys_ftruncate,		"ftruncate"	}, /* 1098 */
-	{ 2,	0,	sys_fchmod,		"fchmod"	}, /* 1099 */
-	{ 3,	0,	sys_fchown,		"fchown"	}, /* 1100 */
+	{ 2,	TD,	sys_ftruncate,		"ftruncate"	}, /* 1098 */
+	{ 2,	TD,	sys_fchmod,		"fchmod"	}, /* 1099 */
+	{ 3,	TD,	sys_fchown,		"fchown"	}, /* 1100 */
 	{ 2,	0,	sys_getpriority,	"getpriority"	}, /* 1101 */
 	{ 3,	0,	sys_setpriority,	"setpriority"	}, /* 1102 */
 	{ 2,	TF,	sys_statfs,		"statfs"	}, /* 1103 */
-	{ 2,	0,	sys_fstatfs,		"fstatfs"	}, /* 1104 */
-	{ 3,	0,	sys_ioperm,		"ioperm"	}, /* 1105 */
+	{ 2,	TD,	sys_fstatfs,		"fstatfs"	}, /* 1104 */
+	{ 3,	0,	printargs,		"gettid"	}, /* 1105 */
 	{ 3,	TI,	sys_semget,		"semget"	}, /* 1106 */
 	{ 3,	TI,	printargs,		"semop"		}, /* 1107 */
 	{ 4,	TI,	sys_semctl,		"semctl"	}, /* 1108 */
@@ -1025,7 +1025,7 @@
 	{ 2,	0,	sys_getitimer,		"getitimer"	}, /* 1119 */
 	{ 2,	TF,	sys_stat,		"stat"		}, /* 1120 */
 	{ 2,	TF,	sys_lstat,		"lstat"		}, /* 1121 */
-	{ 2,	0,	sys_fstat,		"fstat"		}, /* 1122 */
+	{ 2,	TD,	sys_fstat,		"fstat"		}, /* 1122 */
 	{ 0,	0,	sys_vhangup,		"vhangup"	}, /* 1123 */
 	{ 3,	TF,	sys_chown,		"lchown"	}, /* 1124 */
 	{ 5,	0,	printargs,		"vm86"		}, /* 1125 */
@@ -1047,12 +1047,12 @@
 	{ 5,	0,	sys_afs_syscall,	"afs_syscall"	}, /* 1141 */
 	{ 1,	0,	sys_setfsuid,		"setfsuid"	}, /* 1142 */
 	{ 1,	0,	sys_setfsgid,		"setfsgid"	}, /* 1143 */
-	{ 3,	0,	sys_getdents,		"getdents"	}, /* 1144 */
-	{ 2,	0,	sys_flock,		"flock"		}, /* 1145 */
-	{ 5,	0,	sys_readv,		"readv"		}, /* 1146 */
-	{ 5,	0,	sys_writev,		"writev"	}, /* 1147 */
-	{ 4,	0,	sys_pread,		"pread"		}, /* 1148 */
-	{ 4,	0,	sys_pwrite,		"pwrite"	}, /* 1149 */
+	{ 3,	TD,	sys_getdents,		"getdents"	}, /* 1144 */
+	{ 2,	TD,	sys_flock,		"flock"		}, /* 1145 */
+	{ 5,	TD,	sys_readv,		"readv"		}, /* 1146 */
+	{ 5,	TD,	sys_writev,		"writev"	}, /* 1147 */
+	{ 4,	TD,	sys_pread,		"pread"		}, /* 1148 */
+	{ 4,	TD,	sys_pwrite,		"pwrite"	}, /* 1149 */
 	{ 1,	0,	printargs,		"_sysctl"	}, /* 1150 */
 	{ 6,	0,	sys_mmap,		"mmap"		}, /* 1151 */
 	{ 2,	0,	sys_munmap,		"munmap"	}, /* 1152 */
@@ -1090,7 +1090,7 @@
 	{ 2,	TF,	sys_getcwd,		"getcwd"	}, /* 1184 */
 	{ 2,	0,	sys_capget,		"capget"	}, /* 1185 */
 	{ 2,	0,	sys_capset,		"capset"	}, /* 1186 */
-	{ 4,	TF,	sys_sendfile,		"sendfile"	}, /* 1187 */
+	{ 4,	TD,	sys_sendfile,		"sendfile"	}, /* 1187 */
 	{ 5,	TN,	printargs,		"getpmsg"	}, /* 1188 */
 	{ 5,	TN,	printargs,		"putpmsg"	}, /* 1189 */
 	{ 3,	TN,	sys_socket,		"socket"	}, /* 1190 */
@@ -1115,14 +1115,14 @@
 	{ 3,	0,	sys_madvise,		"madvise"	}, /* 1209 */
 	{ 2,	TF,	sys_stat,		"stat"		}, /* 1210 */
 	{ 2,	0,	sys_lstat,		"lstat"		}, /* 1211 */
-	{ 2,	TF,	sys_fstat,		"fstat"		}, /* 1212 */
+	{ 2,	TD,	sys_fstat,		"fstat"		}, /* 1212 */
 	{ 6,	TP,	sys_clone,		"clone2"	}, /* 1213 */
 	{ 3,	0,	printargs,		"getdents64"	}, /* 1214 */
 	{ 2,	0,	printargs,		"getunwind"	}, /* 1215 */
-	{ 4,	0,	sys_readahead,		"readahead"	}, /* 1216 */
+	{ 4,	TD,	sys_readahead,		"readahead"	}, /* 1216 */
 	{ 5,	TF,	sys_setxattr,		"setxattr"	}, /* 1217 */
 	{ 5,	TF,	sys_setxattr,		"lsetxattr"	}, /* 1218 */
-	{ 5,	0,	sys_setxattr,		"fsetxattr"	}, /* 1219 */
+	{ 5,	TD,	sys_setxattr,		"fsetxattr"	}, /* 1219 */
 	{ 4,	TF,	sys_getxattr,		"getxattr"	}, /* 1220 */
 	{ 4,	TF,	sys_getxattr,		"lgetxattr"	}, /* 1221 */
 	{ 4,	0,	sys_getxattr,		"fgetxattr"	}, /* 1222 */
@@ -1137,43 +1137,43 @@
 	{ 3,	0,	sys_sched_setaffinity,	"sched_setaffinity"},/* 1231 */
 	{ 3,	0,	sys_sched_getaffinity,	"sched_getaffinity"},/* 1232 */
 	{ 1,	0,	printargs,		"set_tid_address"}, /* 1233 */
-	{ 8,	0,	printargs,		"SYS_1234"	}, /* 1234 */
+	{ 5,	0,	sys_fadvise64,		"fadvise64"	}, /* 1234 */
 	{ 3,	TS,	sys_tgkill,		"tgkill"	}, /* 1235 */
 	{ 1,	TP,	sys_exit,		"exit_group"	}, /* 1236 */
 	{ 4,	0,	printargs,		"lookup_dcookie"}, /* 1237 */
-	{ 2,	0,	printargs,		"io_setup"	}, /* 1238 */
-	{ 1,	0,	printargs,		"io_destroy"	}, /* 1239 */
-	{ 5,	0,	printargs,		"io_getevents"	}, /* 1240 */
-	{ 3,	0,	printargs,		"io_submit"	}, /* 1241 */
-	{ 3,	0,	printargs,		"io_cancel"	}, /* 1242 */
+	{ 2,	0,	sys_io_setup,		"io_setup"	}, /* 1238 */
+	{ 1,	0,	sys_io_destroy,		"io_destroy"	}, /* 1239 */
+	{ 5,	0,	sys_io_getevents,		"io_getevents"	}, /* 1240 */
+	{ 3,	0,	sys_io_submit,		"io_submit"	}, /* 1241 */
+	{ 3,	0,	sys_io_cancel,		"io_cancel"	}, /* 1242 */
 	{ 1,	0,	sys_epoll_create,	"epoll_create"	}, /* 1243 */
-	{ 4,	0,	sys_epoll_ctl,		"epoll_ctl"	}, /* 1244 */
-	{ 4,	0,	sys_epoll_wait,		"epoll_wait"	}, /* 1245 */
-	{ 8,	0,	printargs,		"SYS_1246"	}, /* 1246 */
-	{ 8,	0,	printargs,		"SYS_1247"	}, /* 1247 */
-	{ 8,	0,	printargs,		"SYS_1248"	}, /* 1248 */
-	{ 8,	0,	printargs,		"SYS_1249"	}, /* 1249 */
-	{ 8,	0,	printargs,		"SYS_1250"	}, /* 1250 */
-	{ 8,	0,	printargs,		"SYS_1251"	}, /* 1251 */
-	{ 8,	0,	printargs,		"SYS_1252"	}, /* 1252 */
-	{ 8,	0,	printargs,		"SYS_1253"	}, /* 1253 */
-	{ 8,	0,	printargs,		"SYS_1254"	}, /* 1254 */
-	{ 8,	0,	printargs,		"SYS_1255"	}, /* 1255 */
-	{ 8,	0,	printargs,		"SYS_1256"	}, /* 1256 */
-	{ 8,	0,	printargs,		"SYS_1257"	}, /* 1257 */
-	{ 8,	0,	printargs,		"SYS_1258"	}, /* 1258 */
-	{ 8,	0,	printargs,		"SYS_1259"	}, /* 1259 */
-	{ 8,	0,	printargs,		"SYS_1260"	}, /* 1260 */
-	{ 8,	0,	printargs,		"SYS_1261"	}, /* 1261 */
-	{ 8,	0,	printargs,		"SYS_1262"	}, /* 1262 */
-	{ 8,	0,	printargs,		"SYS_1263"	}, /* 1263 */
-	{ 8,	0,	printargs,		"SYS_1264"	}, /* 1264 */
-	{ 8,	0,	printargs,		"SYS_1265"	}, /* 1265 */
-	{ 8,	0,	printargs,		"SYS_1266"	}, /* 1266 */
-	{ 8,	0,	printargs,		"SYS_1267"	}, /* 1267 */
-	{ 8,	0,	printargs,		"SYS_1268"	}, /* 1268 */
-	{ 8,	0,	printargs,		"SYS_1269"	}, /* 1269 */
-	{ 8,	0,	printargs,		"SYS_1270"	}, /* 1270 */
+	{ 4,	TD,	sys_epoll_ctl,		"epoll_ctl"	}, /* 1244 */
+	{ 4,	TD,	sys_epoll_wait,		"epoll_wait"	}, /* 1245 */
+	{ 0,	0,	sys_restart_syscall,	"restart_syscall"}, /* 1246 */
+	{ 5,	TI,	sys_semtimedop,		"semtimedop"	}, /* 1247 */
+	{ 3,	0,	sys_timer_create,	"timer_create"	}, /* 1248 */
+	{ 4,	0,	sys_timer_settime,	"timer_settime"	}, /* 1249 */
+	{ 2,	0,	sys_timer_gettime,	"timer_gettime"	}, /* 1250 */
+	{ 1,	0,	sys_timer_getoverrun,	"timer_getoverrun"}, /* 1251 */
+	{ 1,	0,	sys_timer_delete,	"timer_delete"	}, /* 1252 */
+	{ 2,	0,	sys_clock_settime,	"clock_settime"	}, /* 1253 */
+	{ 2,	0,	sys_clock_gettime,	"clock_gettime"	}, /* 1254 */
+	{ 2,	0,	sys_clock_getres,	"clock_getres"	}, /* 1255 */
+	{ 4,	0,	sys_clock_nanosleep,	"clock_nanosleep"}, /* 1256 */
+	{ 8,	0,	printargs,		"fstatfs64"	}, /* 1257 */
+	{ 8,	0,	printargs,		"statfs64"	}, /* 1258 */
+	{ 6,	0,	sys_mbind,		"mbind"		}, /* 1259 */
+	{ 5,	0,	sys_get_mempolicy,	"get_mempolicy"	}, /* 1260 */
+	{ 3,	0,	sys_set_mempolicy,	"set_mempolicy"	}, /* 1261 */
+	{ 4,	0,	sys_mq_open,		"mq_open"	}, /* 1262 */
+	{ 1,	0,	sys_mq_unlink,		"mq_unlink"	}, /* 1263 */
+	{ 5,	0,	sys_mq_timedsend,	"mq_timedsend"	}, /* 1264 */
+	{ 5,	0,	sys_mq_timedreceive,	"mq_timedreceive" }, /* 1265 */
+	{ 2,	0,	sys_mq_notify,		"mq_notify"	}, /* 1266 */
+	{ 3,	0,	sys_mq_getsetattr,	"mq_getsetattr"	}, /* 1267 */
+	{ 5,	0,	printargs,		"sys_kexec_load" }, /* 1268 */
+	{ 5,	0,	printargs,		"vserver"	}, /* 1269 */
+	{ 5,	TP,	sys_waitid,		"waitid"	}, /* 1270 */
 	{ 8,	0,	printargs,		"SYS_1271"	}, /* 1271 */
 	{ 8,	0,	printargs,		"SYS_1272"	}, /* 1272 */
 	{ 8,	0,	printargs,		"SYS_1273"	}, /* 1273 */
