@@ -27,7 +27,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: net.c,v 1.48 2005/06/01 19:22:07 roland Exp $
+ *	$Id: net.c,v 1.51 2005/07/04 23:33:38 roland Exp $
  */
 
 #include "defs.h"
@@ -671,10 +671,10 @@ static const struct xlat sockipoptions[] = {
 	{ IP_RECVERR,		"IP_RECVERR"		},
 #endif
 #ifdef IP_RECVTTL
-	{ IP_RECVTTL,		"IP_RECRECVTTL"		},
+	{ IP_RECVTTL,		"IP_RECVTTL"		},
 #endif
 #ifdef IP_RECVTOS
-	{ IP_RECVTOS,		"IP_RECRECVTOS"		},
+	{ IP_RECVTOS,		"IP_RECVTOS"		},
 #endif
 #ifdef IP_MTU
 	{ IP_MTU,		"IP_MTU"		},
@@ -768,6 +768,15 @@ static const struct xlat sockipv6options[] = {
 #endif
 #ifdef IPV6_FLOWINFO_SEND
 	{ IPV6_FLOWINFO_SEND,	"IPV6_FLOWINFO_SEND"	},
+#endif
+#ifdef IPV6_ADD_MEMBERSHIP
+	{ IPV6_ADD_MEMBERSHIP,	"IPV6_ADD_MEMBERSHIP"	},
+#endif
+#ifdef IPV6_DROP_MEMBERSHIP
+	{ IPV6_DROP_MEMBERSHIP,	"IPV6_DROP_MEMBERSHIP"	},
+#endif
+#ifdef IPV6_ROUTER_ALERT
+	{ IPV6_ROUTER_ALERT,	"IPV6_ROUTER_ALERT"	},
 #endif
 	{ 0,			NULL			},
 };
@@ -1710,7 +1719,7 @@ int len;
 	tprintf (", ");
 
 	if (len == sizeof (int)) {
-		printnum(tcp, addr, "%ld");
+		printnum_int (tcp, addr, "%d");
 	}
 	else {
 		printstr (tcp, addr, len);
