@@ -30,7 +30,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: signal.c,v 1.54 2005/06/01 19:02:37 roland Exp $
+ *	$Id: signal.c,v 1.55 2006/01/12 22:34:50 roland Exp $
  */
 
 #include "defs.h"
@@ -1950,4 +1950,13 @@ int sys_rt_sigtimedwait(tcp)
 	return 0;
 };
 
+int
+sys_restart_syscall(tcp)
+struct tcb *tcp;
+{
+	if (entering(tcp))
+		tprintf("<... resuming interrupted call ...>");
+	return 0;
+}
+
 #endif /* LINUX */
