@@ -26,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: time.c,v 1.11 2004/10/06 22:27:43 roland Exp $
+ *	$Id: time.c,v 1.12 2005/06/01 19:02:38 roland Exp $
  */
 
 #include "defs.h"
@@ -411,8 +411,7 @@ struct tcb *tcp;
 	if (entering(tcp)) {
 		printxval(clocknames, tcp->u_arg[0], "CLOCK_???");
 		tprintf(", ");
-		if (printflags(clockflags, tcp->u_arg[1]) == 0)
-			tprintf("0");
+		printflags(clockflags, tcp->u_arg[1], "TIMER_???");
 		tprintf(", ");
 		printtv(tcp, tcp->u_arg[2]);
 		tprintf(", ");
@@ -493,8 +492,7 @@ struct tcb *tcp;
 {
 	if (entering(tcp)) {
 		tprintf("%#lx, ", tcp->u_arg[0]);
-		if (printflags(clockflags, tcp->u_arg[1]) == 0)
-			tprintf("0");
+		printflags(clockflags, tcp->u_arg[1], "TIMER_???");
 		tprintf(", ");
 		printitv(tcp, tcp->u_arg[2]);
 		tprintf(", ");
