@@ -30,7 +30,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: util.c,v 1.62 2005/06/08 20:45:28 roland Exp $
+ *	$Id: util.c,v 1.64 2005/10/21 22:06:46 roland Exp $
  */
 
 #include "defs.h"
@@ -349,6 +349,27 @@ char *fmt;
 	tprintf("]");
 }
 
+void
+printnum_int(tcp, addr, fmt)
+struct tcb *tcp;
+long addr;
+char *fmt;
+{
+	int num;
+
+	if (!addr) {
+		tprintf("NULL");
+		return;
+	}
+	if (umove(tcp, addr, &num) < 0) {
+		tprintf("%#lx", addr);
+		return;
+	}
+	tprintf("[");
+	tprintf(fmt, num);
+	tprintf("]");
+}
+
 void
 printuid(text, uid)
 const char *text;
@@ -403,6 +424,9 @@ struct tcb *tcp;
 long addr;
 int n;
 {
+	if (n >= sizeof path)
+		n = sizeof path - 1;
+
 	if (addr == 0)
 		tprintf("NULL");
 	else 	if (umovestr(tcp, addr, n, path) < 0)
